openapi

package
v0.0.0-...-f626632 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Overview

Package openapi provides primitives to interact with the openapi HTTP API.

Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.5.0 DO NOT EDIT.

Package openapi provides primitives to interact with the openapi HTTP API.

Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.5.0 DO NOT EDIT.

Package openapi provides primitives to interact with the openapi HTTP API.

Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.5.0 DO NOT EDIT.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetSwagger

func GetSwagger() (swagger *openapi3.T, err error)

GetSwagger returns the Swagger specification corresponding to the generated code in this file. The external references of Swagger specification are resolved. The logic of resolving external references is tightly connected to "import-mapping" feature. Externally referenced files must be embedded in the corresponding golang packages. Urls can be supported but this task was out of the scope.

func PathToRawSpec

func PathToRawSpec(pathToFile string) map[string]func() ([]byte, error)

Constructs a synthetic filesystem for resolving external references when loading openapi specifications.

func RegisterHandlers

func RegisterHandlers(router EchoRouter, si ServerInterface)

RegisterHandlers adds each server route to the EchoRouter.

func RegisterHandlersWithBaseURL

func RegisterHandlersWithBaseURL(router EchoRouter, si ServerInterface, baseURL string)

Registers handlers, and prepends BaseURL to the paths, so that the paths can be served under a prefix.

Types

type BorrowReply

type BorrowReply struct {
	Answer  bool   `json:"answer"`
	Comment string `json:"comment"`
}

BorrowReply defines model for borrowReply.

type BorrowRequest

type BorrowRequest struct {
	BorrowInClubRoom bool               `json:"borrowInClubRoom"`
	DueDate          openapi_types.Date `json:"dueDate"`
	Propose          *string            `json:"propose,omitempty"`
}

BorrowRequest defines model for borrowRequest.

type BorrowRequestEquipment

type BorrowRequestEquipment struct {
	BorrowInClubRoom bool               `json:"borrowInClubRoom"`
	Count            *int               `json:"count,omitempty"`
	DueDate          openapi_types.Date `json:"dueDate"`
	Propose          *string            `json:"propose,omitempty"`
}

BorrowRequestEquipment defines model for borrowRequestEquipment.

type BorrowReturn

type BorrowReturn struct {
	Text string `json:"text"`
}

BorrowReturn defines model for borrowReturn.

type Borrowing

type Borrowing struct {
	BorrowInClubRoom bool               `json:"borrowInClubRoom"`
	DueDate          openapi_types.Date `json:"dueDate"`
	Id               int                `json:"id"`
	Propose          *string            `json:"propose,omitempty"`
}

Borrowing defines model for borrowing.

type BorrowingIdInPath

type BorrowingIdInPath = int

BorrowingIdInPath defines model for borrowingIdInPath.

type Comment

type Comment struct {
	CreatedAt *time.Time                   `json:"createdAt,omitempty"`
	DeletedAt nullable.Nullable[time.Time] `json:"deletedAt,omitempty"`
	Id        *int                         `json:"id,omitempty"`
	Item      *ItemSummary                 `json:"item,omitempty"`
	ItemId    *int                         `json:"itemId,omitempty"`
	Text      string                       `json:"text"`
	UpdatedAt *time.Time                   `json:"updatedAt,omitempty"`
	UserId    *string                      `json:"userId,omitempty"`
}

Comment defines model for comment.

type EchoRouter

type EchoRouter interface {
	CONNECT(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	DELETE(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	GET(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	HEAD(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	OPTIONS(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	PATCH(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	POST(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	PUT(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
	TRACE(path string, h echo.HandlerFunc, m ...echo.MiddlewareFunc) *echo.Route
}

This is a simple interface which specifies echo.Route addition functions which are present on both echo.Echo and echo.Group, since we want to allow using either of them for path registration

type EditItemJSONRequestBody

type EditItemJSONRequestBody = ItemPostRequest

EditItemJSONRequestBody defines body for EditItem for application/json ContentType.

type EditItemOwnersJSONRequestBody

type EditItemOwnersJSONRequestBody = PostOwnership

EditItemOwnersJSONRequestBody defines body for EditItemOwners for application/json ContentType.

type File

type File struct {
	// Id ファイルID
	Id int `json:"id"`

	// Url ファイルURL
	Url string `json:"url"`
}

File defines model for file.

type FileIdInPath

type FileIdInPath = int

FileIdInPath defines model for fileIdInPath.

type GetItemsParams

type GetItemsParams struct {
	// UserId 指定したユーザーの所有する物品一覧を取得します。
	UserId *string `form:"userId,omitempty" json:"userId,omitempty"`

	// Search 名称が部分一致する物品一覧を取得します。
	Search *string `form:"search,omitempty" json:"search,omitempty"`

	// Rental 指定したユーザーの借りている物品一覧を取得します。
	Rental *string `form:"rental,omitempty" json:"rental,omitempty"`

	// Limit 取得したい件数を指定します。リクエストした件数が全部の件数より多い場合は全部の一覧になります。
	Limit *int `form:"limit,omitempty" json:"limit,omitempty"`

	// Offset 取得したいデータの開始場所を指定します。リクエストした件数が全部の件数より多い場合は空の配列が返ってきます。
	Offset *int `form:"offset,omitempty" json:"offset,omitempty"`

	// Tag リクエストしたタグのついている物品一覧を取得します。
	Tag *[]string `form:"tag,omitempty" json:"tag,omitempty"`

	// TagExclude リクエストしたタグのついている物品一覧を除外します
	TagExclude *[]string `form:"tag-exclude,omitempty" json:"tag-exclude,omitempty"`

	// Sortby 何の要素でソートするか
	Sortby *string `form:"sortby,omitempty" json:"sortby,omitempty"`
}

GetItemsParams defines parameters for GetItems.

type IsBook

type IsBook = bool

IsBook アイテム種別 本でない/本

type IsEquipment

type IsEquipment = bool

IsEquipment アイテム種別 個人所有/備品

type Item

type Item struct {
	Code        *string                      `json:"code,omitempty"`
	Comments    *[]Comment                   `json:"comments,omitempty"`
	Count       *int                         `json:"count,omitempty"`
	CreatedAt   time.Time                    `json:"createdAt"`
	DeletedAt   nullable.Nullable[time.Time] `json:"deletedAt"`
	Description string                       `json:"description"`
	Id          int                          `json:"id"`
	ImgUrl      string                       `json:"imgUrl"`

	// IsBook アイテム種別 本でない/本
	IsBook IsBook `json:"isBook"`

	// IsTrapItem アイテム種別 個人所有/備品
	IsTrapItem IsEquipment `json:"isTrapItem"`
	Name       string      `json:"name"`
	Tags       *[]Tag      `json:"tags,omitempty"`
	UpdatedAt  time.Time   `json:"updatedAt"`
	// contains filtered or unexported fields
}

Item defines model for item.

func (Item) AsItem0

func (t Item) AsItem0() (Item0, error)

AsItem0 returns the union data inside the Item as a Item0

func (Item) AsItem1

func (t Item) AsItem1() (Item1, error)

AsItem1 returns the union data inside the Item as a Item1

func (*Item) FromItem0

func (t *Item) FromItem0(v Item0) error

FromItem0 overwrites any union data inside the Item as the provided Item0

func (*Item) FromItem1

func (t *Item) FromItem1(v Item1) error

FromItem1 overwrites any union data inside the Item as the provided Item1

func (Item) MarshalJSON

func (t Item) MarshalJSON() ([]byte, error)

func (*Item) MergeItem0

func (t *Item) MergeItem0(v Item0) error

MergeItem0 performs a merge with any union data inside the Item, using the provided Item0

func (*Item) MergeItem1

func (t *Item) MergeItem1(v Item1) error

MergeItem1 performs a merge with any union data inside the Item, using the provided Item1

func (*Item) UnmarshalJSON

func (t *Item) UnmarshalJSON(b []byte) error

type Item0

type Item0 struct {
	Count    int `json:"count"`
	CountMax int `json:"countMax"`
}

Item0 defines model for .

type Item1

type Item1 struct {
	Ownerships []Ownership `json:"ownerships"`
}

Item1 defines model for .

type ItemDetail

type ItemDetail struct {
	Code        *string                      `json:"code,omitempty"`
	Comments    *[]Comment                   `json:"comments,omitempty"`
	Count       *int                         `json:"count,omitempty"`
	CreatedAt   time.Time                    `json:"createdAt"`
	DeletedAt   nullable.Nullable[time.Time] `json:"deletedAt"`
	Description string                       `json:"description"`
	Id          int                          `json:"id"`
	ImgUrl      string                       `json:"imgUrl"`

	// IsBook アイテム種別 本でない/本
	IsBook IsBook `json:"isBook"`

	// IsTrapItem アイテム種別 個人所有/備品
	IsTrapItem   IsEquipment `json:"isTrapItem"`
	LikesByUsers *[]string   `json:"likesByUsers,omitempty"`
	Name         string      `json:"name"`
	Tags         *[]Tag      `json:"tags,omitempty"`
	UpdatedAt    time.Time   `json:"updatedAt"`
	// contains filtered or unexported fields
}

ItemDetail defines model for itemDetail.

func (ItemDetail) AsItemDetail0

func (t ItemDetail) AsItemDetail0() (ItemDetail0, error)

AsItemDetail0 returns the union data inside the ItemDetail as a ItemDetail0

func (ItemDetail) AsItemDetail1

func (t ItemDetail) AsItemDetail1() (ItemDetail1, error)

AsItemDetail1 returns the union data inside the ItemDetail as a ItemDetail1

func (*ItemDetail) FromItemDetail0

func (t *ItemDetail) FromItemDetail0(v ItemDetail0) error

FromItemDetail0 overwrites any union data inside the ItemDetail as the provided ItemDetail0

func (*ItemDetail) FromItemDetail1

func (t *ItemDetail) FromItemDetail1(v ItemDetail1) error

FromItemDetail1 overwrites any union data inside the ItemDetail as the provided ItemDetail1

func (ItemDetail) MarshalJSON

func (t ItemDetail) MarshalJSON() ([]byte, error)

func (*ItemDetail) MergeItemDetail0

func (t *ItemDetail) MergeItemDetail0(v ItemDetail0) error

MergeItemDetail0 performs a merge with any union data inside the ItemDetail, using the provided ItemDetail0

func (*ItemDetail) MergeItemDetail1

func (t *ItemDetail) MergeItemDetail1(v ItemDetail1) error

MergeItemDetail1 performs a merge with any union data inside the ItemDetail, using the provided ItemDetail1

func (*ItemDetail) UnmarshalJSON

func (t *ItemDetail) UnmarshalJSON(b []byte) error

type ItemDetail0

type ItemDetail0 struct {
	TransactionsEquipment []TransactionEquipment `json:"transactionsEquipment"`
}

ItemDetail0 defines model for .

type ItemDetail1

type ItemDetail1 struct {
	Transactions []Transaction `json:"transactions"`
}

ItemDetail1 defines model for .

type ItemIdInPath

type ItemIdInPath = int

ItemIdInPath defines model for itemIdInPath.

type ItemPostRequest

type ItemPostRequest struct {
	Code        *string `json:"code,omitempty"`
	Count       *int    `json:"count,omitempty"`
	Description string  `json:"description"`
	ImgUrl      string  `json:"imgUrl"`

	// IsBook アイテム種別 本でない/本
	IsBook IsBook `json:"isBook"`

	// IsTrapItem アイテム種別 個人所有/備品
	IsTrapItem IsEquipment `json:"isTrapItem"`
	Name       string      `json:"name"`
	Tags       *[]string   `json:"tags,omitempty"`
}

ItemPostRequest defines model for itemPostRequest.

type ItemPosted

type ItemPosted struct {
	Code        *string                      `json:"code,omitempty"`
	Count       *int                         `json:"count,omitempty"`
	CreatedAt   time.Time                    `json:"createdAt"`
	DeletedAt   nullable.Nullable[time.Time] `json:"deletedAt"`
	Description string                       `json:"description"`
	Id          int                          `json:"id"`
	ImgUrl      string                       `json:"imgUrl"`

	// IsBook アイテム種別 本でない/本
	IsBook IsBook `json:"isBook"`

	// IsTrapItem アイテム種別 個人所有/備品
	IsTrapItem IsEquipment `json:"isTrapItem"`
	Name       string      `json:"name"`
	Tags       *[]string   `json:"tags,omitempty"`
	UpdatedAt  time.Time   `json:"updatedAt"`
}

ItemPosted defines model for itemPosted.

type ItemSummary

type ItemSummary struct {
	Code        *string                      `json:"code,omitempty"`
	Comments    *[]Comment                   `json:"comments,omitempty"`
	Count       *int                         `json:"count,omitempty"`
	CreatedAt   time.Time                    `json:"createdAt"`
	DeletedAt   nullable.Nullable[time.Time] `json:"deletedAt"`
	Description string                       `json:"description"`
	Id          int                          `json:"id"`
	ImgUrl      string                       `json:"imgUrl"`

	// IsBook アイテム種別 本でない/本
	IsBook  IsBook `json:"isBook"`
	IsLiked *bool  `json:"isLiked,omitempty"`

	// IsTrapItem アイテム種別 個人所有/備品
	IsTrapItem IsEquipment `json:"isTrapItem"`
	LikeCounts *int        `json:"likeCounts,omitempty"`
	Name       string      `json:"name"`
	Tags       *[]Tag      `json:"tags,omitempty"`
	UpdatedAt  time.Time   `json:"updatedAt"`
}

ItemSummary defines model for itemSummary.

type Owner

type Owner struct {
	Count      int       `json:"count"`
	CreatedAt  time.Time `json:"createdAt"`
	DeletedAt  time.Time `json:"deletedAt"`
	Id         int       `json:"id"`
	OwnerId    int       `json:"ownerId"`
	Rentalable bool      `json:"rentalable"`
	UpdatedAt  time.Time `json:"updatedAt"`
	UserId     string    `json:"userId"`
}

Owner defines model for owner.

type Ownership

type Ownership struct {
	Id          *int         `json:"id,omitempty"`
	ItemId      *int         `json:"itemId,omitempty"`
	Memo        string       `json:"memo"`
	Rentalable  bool         `json:"rentalable"`
	Transaction *Transaction `json:"transaction,omitempty"`
	UserId      string       `json:"userId"`
}

Ownership defines model for ownership.

type OwnershipIdInPath

type OwnershipIdInPath = int

OwnershipIdInPath defines model for ownershipIdInPath.

type PostBorrowEquipmentJSONRequestBody

type PostBorrowEquipmentJSONRequestBody = BorrowRequestEquipment

PostBorrowEquipmentJSONRequestBody defines body for PostBorrowEquipment for application/json ContentType.

type PostBorrowEquipmentReturnJSONRequestBody

type PostBorrowEquipmentReturnJSONRequestBody = BorrowReturn

PostBorrowEquipmentReturnJSONRequestBody defines body for PostBorrowEquipmentReturn for application/json ContentType.

type PostBorrowJSONRequestBody

type PostBorrowJSONRequestBody = BorrowRequest

PostBorrowJSONRequestBody defines body for PostBorrow for application/json ContentType.

type PostBorrowReplyJSONRequestBody

type PostBorrowReplyJSONRequestBody = BorrowReply

PostBorrowReplyJSONRequestBody defines body for PostBorrowReply for application/json ContentType.

type PostComment

type PostComment struct {
	Text string `json:"text"`
}

PostComment defines model for postComment.

type PostCommentJSONRequestBody

type PostCommentJSONRequestBody = PostComment

PostCommentJSONRequestBody defines body for PostComment for application/json ContentType.

type PostFileMultipartBody

type PostFileMultipartBody struct {
	// File 3MBまでのJPG, PNGファイル
	File *openapi_types.File `json:"file,omitempty"`
}

PostFileMultipartBody defines parameters for PostFile.

type PostFileMultipartRequestBody

type PostFileMultipartRequestBody PostFileMultipartBody

PostFileMultipartRequestBody defines body for PostFile for multipart/form-data ContentType.

type PostItemJSONBody

type PostItemJSONBody = []ItemPostRequest

PostItemJSONBody defines parameters for PostItem.

type PostItemJSONRequestBody

type PostItemJSONRequestBody = PostItemJSONBody

PostItemJSONRequestBody defines body for PostItem for application/json ContentType.

type PostItemOwnersJSONRequestBody

type PostItemOwnersJSONRequestBody = PostOwnership

PostItemOwnersJSONRequestBody defines body for PostItemOwners for application/json ContentType.

type PostOwnership

type PostOwnership struct {
	Memo       string `json:"memo"`
	Rentalable bool   `json:"rentalable"`
	UserId     string `json:"userId"`
}

PostOwnership defines model for postOwnership.

type PostReturnJSONRequestBody

type PostReturnJSONRequestBody = BorrowReturn

PostReturnJSONRequestBody defines body for PostReturn for application/json ContentType.

type ServerInterface

type ServerInterface interface {
	// 画像ファイルをアップロードします。
	// (POST /files)
	PostFile(ctx echo.Context) error
	// 画像ファイルをダウンロードします。
	// (GET /files/{fileId})
	GetFile(ctx echo.Context, fileId FileIdInPath) error
	// 物品の一覧を取得します。
	// (GET /items)
	GetItems(ctx echo.Context, params GetItemsParams) error
	// 物品を新しく登録します。
	// (POST /items)
	PostItem(ctx echo.Context) error
	// 物品を削除します。
	// (DELETE /items/{itemId})
	DeleteItem(ctx echo.Context, itemId ItemIdInPath) error
	// 物品の詳細情報を取得します。
	// (GET /items/{itemId})
	GetItem(ctx echo.Context, itemId ItemIdInPath) error
	// 物品の情報を変更します。
	// (PATCH /items/{itemId})
	EditItem(ctx echo.Context, itemId ItemIdInPath) error
	// 備品を借ります。
	// (POST /items/{itemId}/borrowing/equipment)
	PostBorrowEquipment(ctx echo.Context, itemId ItemIdInPath) error
	// 備品を返します。
	// (POST /items/{itemId}/borrowing/equipment/return)
	PostBorrowEquipmentReturn(ctx echo.Context, itemId ItemIdInPath) error
	// コメントを新規作成します。
	// (POST /items/{itemId}/comments)
	PostComment(ctx echo.Context, itemId ItemIdInPath) error
	// 物品のいいねを取り消します。
	// (DELETE /items/{itemId}/likes)
	RemoveLike(ctx echo.Context, itemId ItemIdInPath) error
	// 物品にいいねをつけます。
	// (POST /items/{itemId}/likes)
	AddLike(ctx echo.Context, itemId ItemIdInPath) error
	// 物品の所有者を追加します。
	// (POST /items/{itemId}/owners)
	PostItemOwners(ctx echo.Context, itemId ItemIdInPath) error
	// 物品の所有者を削除します
	// (DELETE /items/{itemId}/owners/{ownershipId})
	DeleteItemOwners(ctx echo.Context, itemId ItemIdInPath, ownershipId OwnershipIdInPath) error
	// 物品の所有者を編集します。(所有者と管理者のみ)
	// (PATCH /items/{itemId}/owners/{ownershipId})
	EditItemOwners(ctx echo.Context, itemId ItemIdInPath, ownershipId OwnershipIdInPath) error
	// 個人所有物を「借りたい」と意見表明します。
	// (POST /items/{itemId}/owners/{ownershipId}/borrowings)
	PostBorrow(ctx echo.Context, itemId ItemIdInPath, ownershipId OwnershipIdInPath) error
	// 個人所有物を借りたいという要望を取得します。 (○○日に借りたい、○○日に返す予定、など)
	// (GET /items/{itemId}/owners/{ownershipId}/borrowings/{borrowingId})
	GetBorrowingById(ctx echo.Context, itemId ItemIdInPath, ownershipId OwnershipIdInPath, borrowingId BorrowingIdInPath) error
	// 個人所有物を○○日まで借りたいという要望に対して返答します。
	// (POST /items/{itemId}/owners/{ownershipId}/borrowings/{borrowingId}/reply)
	PostBorrowReply(ctx echo.Context, itemId ItemIdInPath, ownershipId OwnershipIdInPath, borrowingId BorrowingIdInPath) error
	// 個人所有物を返します。
	// (POST /items/{itemId}/owners/{ownershipId}/borrowings/{borrowingId}/return)
	PostReturn(ctx echo.Context, itemId ItemIdInPath, ownershipId OwnershipIdInPath, borrowingId BorrowingIdInPath) error
}

ServerInterface represents all server handlers.

type ServerInterfaceWrapper

type ServerInterfaceWrapper struct {
	Handler ServerInterface
}

ServerInterfaceWrapper converts echo contexts to parameters.

func (*ServerInterfaceWrapper) AddLike

func (w *ServerInterfaceWrapper) AddLike(ctx echo.Context) error

AddLike converts echo context to params.

func (*ServerInterfaceWrapper) DeleteItem

func (w *ServerInterfaceWrapper) DeleteItem(ctx echo.Context) error

DeleteItem converts echo context to params.

func (*ServerInterfaceWrapper) DeleteItemOwners

func (w *ServerInterfaceWrapper) DeleteItemOwners(ctx echo.Context) error

DeleteItemOwners converts echo context to params.

func (*ServerInterfaceWrapper) EditItem

func (w *ServerInterfaceWrapper) EditItem(ctx echo.Context) error

EditItem converts echo context to params.

func (*ServerInterfaceWrapper) EditItemOwners

func (w *ServerInterfaceWrapper) EditItemOwners(ctx echo.Context) error

EditItemOwners converts echo context to params.

func (*ServerInterfaceWrapper) GetBorrowingById

func (w *ServerInterfaceWrapper) GetBorrowingById(ctx echo.Context) error

GetBorrowingById converts echo context to params.

func (*ServerInterfaceWrapper) GetFile

func (w *ServerInterfaceWrapper) GetFile(ctx echo.Context) error

GetFile converts echo context to params.

func (*ServerInterfaceWrapper) GetItem

func (w *ServerInterfaceWrapper) GetItem(ctx echo.Context) error

GetItem converts echo context to params.

func (*ServerInterfaceWrapper) GetItems

func (w *ServerInterfaceWrapper) GetItems(ctx echo.Context) error

GetItems converts echo context to params.

func (*ServerInterfaceWrapper) PostBorrow

func (w *ServerInterfaceWrapper) PostBorrow(ctx echo.Context) error

PostBorrow converts echo context to params.

func (*ServerInterfaceWrapper) PostBorrowEquipment

func (w *ServerInterfaceWrapper) PostBorrowEquipment(ctx echo.Context) error

PostBorrowEquipment converts echo context to params.

func (*ServerInterfaceWrapper) PostBorrowEquipmentReturn

func (w *ServerInterfaceWrapper) PostBorrowEquipmentReturn(ctx echo.Context) error

PostBorrowEquipmentReturn converts echo context to params.

func (*ServerInterfaceWrapper) PostBorrowReply

func (w *ServerInterfaceWrapper) PostBorrowReply(ctx echo.Context) error

PostBorrowReply converts echo context to params.

func (*ServerInterfaceWrapper) PostComment

func (w *ServerInterfaceWrapper) PostComment(ctx echo.Context) error

PostComment converts echo context to params.

func (*ServerInterfaceWrapper) PostFile

func (w *ServerInterfaceWrapper) PostFile(ctx echo.Context) error

PostFile converts echo context to params.

func (*ServerInterfaceWrapper) PostItem

func (w *ServerInterfaceWrapper) PostItem(ctx echo.Context) error

PostItem converts echo context to params.

func (*ServerInterfaceWrapper) PostItemOwners

func (w *ServerInterfaceWrapper) PostItemOwners(ctx echo.Context) error

PostItemOwners converts echo context to params.

func (*ServerInterfaceWrapper) PostReturn

func (w *ServerInterfaceWrapper) PostReturn(ctx echo.Context) error

PostReturn converts echo context to params.

func (*ServerInterfaceWrapper) RemoveLike

func (w *ServerInterfaceWrapper) RemoveLike(ctx echo.Context) error

RemoveLike converts echo context to params.

type Tag

type Tag struct {
	Name string `json:"name"`
}

Tag defines model for tag.

type TagIdInPath

type TagIdInPath = int

TagIdInPath defines model for tagIdInPath.

type Transaction

type Transaction struct {
	CheckoutDate  openapi_types.Date           `json:"checkout_date"`
	CreatedAt     *time.Time                   `json:"createdAt,omitempty"`
	DeletedAt     nullable.Nullable[time.Time] `json:"deletedAt,omitempty"`
	DueDate       openapi_types.Date           `json:"due_date"`
	Id            *int                         `json:"id,omitempty"`
	Message       string                       `json:"message"`
	OwnershipId   *int                         `json:"ownershipId,omitempty"`
	Purpose       *string                      `json:"purpose,omitempty"`
	ReturnMessage string                       `json:"returnMessage"`
	ReturnDate    openapi_types.Date           `json:"return_date"`

	// Status 0=リクエスト済み、1=貸し出し中、2=返却済み、3=貸し出し拒否
	Status    *int       `json:"status,omitempty"`
	UpdatedAt *time.Time `json:"updatedAt,omitempty"`
	UserId    *string    `json:"userId,omitempty"`
}

Transaction defines model for transaction.

type TransactionEquipment

type TransactionEquipment struct {
	CreatedAt  *time.Time                   `json:"createdAt,omitempty"`
	DeletedAt  nullable.Nullable[time.Time] `json:"deletedAt,omitempty"`
	DueDate    openapi_types.Date           `json:"due_date"`
	Id         *int                         `json:"id,omitempty"`
	ItemId     *int                         `json:"itemId,omitempty"`
	Purpose    *string                      `json:"purpose,omitempty"`
	ReturnDate openapi_types.Date           `json:"return_date"`

	// Status 0=リクエスト済み、1=貸し出し中、2=返却済み、3=貸し出し拒否
	Status    *int       `json:"status,omitempty"`
	UpdatedAt *time.Time `json:"updatedAt,omitempty"`
	UserId    *string    `json:"userId,omitempty"`
}

TransactionEquipment defines model for transactionEquipment.

Jump to